Docker container state machine Docker container execution state machine.
Modules
- crypto
- Cryptographic utilities for container state encryption.
- docker_
utils - Docker-specific helper utilities.
- state
- State types for the container state machine.
- transitions
- State machine transitions for containers.
Structs
- Container
Metadata - Metadata associated with a container executing a workflow step.
- Container
Metrics - Metrics collected during or after the container’s execution.
- Docker
Container Machine - The core state machine representing a Docker container’s lifecycle.
Enums
- Container
State - The final outcome state of the container.
- Start
Result - The result of attempting to start the container.