pub struct ContainerMetrics {
pub exit_code: Option<i64>,
pub duration_ms: u64,
pub latency_ms: u64,
pub storage_hashes: Option<HashMap<String, String>>,
pub artifacts: Option<HashMap<String, Value>>,
pub test_reports: Option<Value>,
}Expand description
Metrics collected during or after the container’s execution.
Fields
exit_code: Option<i64>The exit code of the container, if it has finished.
duration_ms: u64How long the container ran in milliseconds.
latency_ms: u64How long the container took to start after being received, in milliseconds.
storage_hashes: Option<HashMap<String, String>>Hashes of the storage artifacts generated by the container.
artifacts: Option<HashMap<String, Value>>Artifacts generated by the container.
test_reports: Option<Value>Test reports generated by the container.